@@ -18,7 +18,7 @@ use IPC::SysV qw(
 use Storable 0.6 qw(freeze thaw);
 use Scalar::Util;
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 $SIG{CHLD} = 'IGNORE';
 
@@ -592,7 +592,7 @@ sub _tie {
 
         if (! defined $exclusive) {
             if ($opts->{warn}) {
-                warn "Process ID $$ exited due to exclusive shared memory collision";
+                warn "Process ID $$ exited due to exclusive shared memory collision\n";
             }
             exit(0);
         }
